==> mail-notification-0.3.2.tar.gz: mail-notification-0.3.2/src/mn-mail-icon.h <==
/* 
 * Copyright (c) 2003 Jean-Yves Lefort <jylefort@brutele.be>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _MN_MAIL_ICON_H
#define _MN_MAIL_ICON_H

#include "eggtrayicon.h"

#define MN_TYPE_MAIL_ICON		(mn_mail_icon_get_type())
#define MN_MAIL_ICON(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), MN_TYPE_MAIL_ICON, MNMailIcon))
#define MN_MAIL_ICON_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), MN_TYPE_MAIL_ICON, MNMailIconClass))
#define MN_IS_MAIL_ICON(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), MN_TYPE_MAIL_ICON))
#define MN_IS_MAIL_ICON_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), MN_TYPE_MAIL_ICON))
#define MN_MAIL_ICON_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), MN_TYPE_MAIL_ICON, MNMailIconClass))

typedef struct _MNMailIconPrivate MNMailIconPrivate;

typedef struct
{
  EggTrayIcon		icon;

  MNMailIconPrivate	*priv;
} MNMailIcon;

typedef struct
{
  EggTrayIconClass	icon_class;
} MNMailIconClass;

GType		mn_mail_icon_get_type		(void);

GtkWidget	*mn_mail_icon_new		(void);
void		mn_mail_icon_set_has_new	(MNMailIcon	*icon,
						 gboolean	has_new);
void		mn_mail_icon_set_can_check	(MNMailIcon	*icon,
						 gboolean	can_check);

#endif /* _MN_MAIL_ICON_H */

==> mail-notification-0.3.4.tar.gz: mail-notification-0.3.4/src/mn-mail-icon.h <==
/* 
 * Copyright (c) 2003, 2004 Jean-Yves Lefort <jylefort@brutele.be>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _MN_MAIL_ICON_H
#define _MN_MAIL_ICON_H

#include <gtk/gtk.h>
#include "eggtrayicon.h"

#define MN_TYPE_MAIL_ICON		(mn_mail_icon_get_type())
#define MN_MAIL_ICON(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), MN_TYPE_MAIL_ICON, MNMailIcon))
#define MN_MAIL_ICON_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), MN_TYPE_MAIL_ICON, MNMailIconClass))
#define MN_IS_MAIL_ICON(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), MN_TYPE_MAIL_ICON))
#define MN_IS_MAIL_ICON_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), MN_TYPE_MAIL_ICON))
#define MN_MAIL_ICON_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), MN_TYPE_MAIL_ICON, MNMailIconClass))

typedef struct _MNMailIconPrivate MNMailIconPrivate;

typedef struct
{
  EggTrayIcon		icon;

  MNMailIconPrivate	*priv;
} MNMailIcon;

typedef struct
{
  EggTrayIconClass	icon_class;

  /* signals */
  void (*activate) (void);
} MNMailIconClass;

GType		mn_mail_icon_get_type		(void);

GtkWidget	*mn_mail_icon_new		(void);
void		mn_mail_icon_set_popup_menu	(MNMailIcon	*icon,
						 GtkMenu	*menu);
void		mn_mail_icon_set_has_new	(MNMailIcon	*icon,
						 gboolean	has_new);

#endif /* _MN_MAIL_ICON_H */
